import sys
import typing

GenericType = typing.TypeVar("GenericType")


def connect_sockets(input, output):
    ''' 

    '''

    pass


def find_base_socket_type(socket):
    ''' 

    '''

    pass


def find_node_input(node, name):
    ''' 

    '''

    pass
