import sys
import typing

GenericType = typing.TypeVar("GenericType")


class _ext_global:
    idmap = None
    ''' '''

    module_handle = None
    ''' '''


def check(module_name):
    ''' 

    '''

    pass


def disable(module_name, default_set, handle_error):
    ''' 

    '''

    pass


def disable_all():
    ''' 

    '''

    pass


def enable(module_name, default_set, persistent, handle_error):
    ''' 

    '''

    pass


def module_bl_info(mod, info_basis):
    ''' 

    '''

    pass


def modules(module_cache, refresh):
    ''' 

    '''

    pass


def modules_refresh(module_cache):
    ''' 

    '''

    pass


def paths():
    ''' 

    '''

    pass


def reset_all(reload_scripts):
    ''' 

    '''

    pass
